/*
 *    NzdlPreferences.java
 *    Copyright (C) 2001 New Zealand Digital Library Project
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

//the package we're in
package org.nzdl.gsdl.util;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Hashtable;
import java.util.Properties;


/**
 * Stores our preferences...
 */
public final class NzdlPreferences {
  /** The hashtable we write to disk ... */
  protected Properties _preferences = null;
  /** 
   * Should we save the preferences? Should normally be true for
   * GUI work and false for commandline and/or server work.
   */
  public static boolean saving = true;
  /** The singleton instance */
  static NzdlPreferences instance = null;
  static String preferencesFileName = "preferences";

  protected NzdlPreferences() {
    try {
      _preferences = new Properties();
      String dir = System.getProperties().getProperty("user.home");
      String sep = System.getProperties().getProperty("file.separator");

      File file = new File(dir + sep + preferencesFileName);
      InputStream stream = new FileInputStream(file);
      _preferences.load(stream);
    } catch (Exception exception) {
      System.out.println("Unable to load file " + preferencesFileName+ "\n" + exception);
    }
  }

  public void save() {
    if (!saving)
      return;
    try {
      String dir = System.getProperties().getProperty("user.home");
      String sep = System.getProperties().getProperty("file.separator");

      File file = new File(dir + sep + preferencesFileName);
      OutputStream stream = new FileOutputStream(file);
      _preferences.store(stream,"Preferences ...");
    } catch (Exception exception) {
      System.out.println("Unable to save file " + preferencesFileName + "\n" + exception);
      System.out.println("preferences =" + _preferences);
    }
  }
  
  /**
   * Get the static Preferences object
   */
  public static NzdlPreferences getInstance() {
    if (instance == null)
      instance = new NzdlPreferences();
    return instance;
  }
  /**
   * Get a boolean preference
   */
  public static boolean getBoolean(String key){
    String value = (String) getInstance()._preferences.get(key);
    if (value == null)
      {
	setBoolean(key,false);
	return false;
      }
    return Boolean.valueOf(value).booleanValue();
  }
  /**
   * Set a boolean preference
   */
  public static void setBoolean(String key,boolean value) {
    getInstance()._preferences.put(key,"" + value);
    getInstance().save();
  }


    public static boolean isBoolean(String key) {
	String value = (String) getInstance()._preferences.get(key);
	if (value == null)
		return false;
	return true;
    }

  /**
   * Get a String preference
   */
  public static String getString(String key){
    String value = (String) getInstance()._preferences.get(key);
    if (value == null)
      {
	setString(key,"");
	return "";
      }
    return value;
  }

    public static boolean isString(String key){
	//String value = (String) getInstance()._preferences.get(key);
	if (getInstance()._preferences.get(key) == null )
	    return false;
	else
	    return true;
    }



  /**
   * Set a String preference
   */
  public static void setString(String key, String value) {
    getInstance()._preferences.put(key, value);
    getInstance().save();
  }
}

